"""
test iotools for panond
"""

from pvlib.iotools import read_panond
from pvlib.tests.conftest import DATA_DIR

PAN_FILE = DATA_DIR / 'ET-M772BH550GL.PAN'
OND_FILE = DATA_DIR / 'CPS SCH275KTL-DO-US-800-250kW_275kVA_1.OND'


def test_read_panond():
    # test that returned contents have expected keys, types, and structure

    pan = read_panond(PAN_FILE, encoding='utf-8-sig')
    assert list(pan.keys()) == ['PVObject_']
    pan = pan['PVObject_']
    assert pan['PVObject_Commercial']['Model'] == 'ET-M772BH550GL'
    assert pan['Voc'] == 49.9
    assert pan['PVObject_IAM']['IAMProfile']['Point_5'] == [50.0, 0.98]
    assert pan['BifacialityFactor'] == 0.7
    assert pan['FrontSurface'] == 'fsARCoating'
    assert pan['Technol'] == 'mtSiMono'

    ond = read_panond(OND_FILE, encoding='utf-8-sig')
    assert list(ond.keys()) == ['PVObject_']
    ond = ond['PVObject_']
    assert ond['PVObject_Commercial']['Model'] == 'CPS SCH275KTL-DO/US-800'
    assert ond['TanPhiMin'] == -0.75
    assert ond['NbMPPT'] == 12
    assert ond['Converter']['ModeOper'] == 'MPPT'
    assert ond['Converter']['ProfilPIOV2']['Point_5'] == [75795.9, 75000.0]
